/**
 * \file gammu.h
 * \author Michal Čihař
 *
 * Top level include for applications.
 */
#ifndef __gammu_gammu_h
#define __gammu_gammu_h

#ifdef	__cplusplus
extern "C" {
#endif

#include <gammu-types.h>
#include <gammu-statemachine.h>
#include <gammu-error.h>
#include <gammu-inifile.h>
#include <gammu-backup.h>
#include <gammu-config.h>
#include <gammu-nokia.h>
#include <gammu-call.h>
#include <gammu-security.h>
#include <gammu-keys.h>
#include <gammu-call.h>
#include <gammu-calendar.h>
#include <gammu-callback.h>
#include <gammu-category.h>
#include <gammu-message.h>
#include <gammu-file.h>
#include <gammu-ringtone.h>
#include <gammu-info.h>
#include <gammu-unicode.h>
#include <gammu-misc.h>
#include <gammu-debug.h>

#ifdef	__cplusplus
}
#endif
#endif
/* Editor configuration
 * vim: noexpandtab sw=8 ts=8 sts=8 tw=72:
 */
